macro_rules! log_enabled {
($e:expr) => { ... };
}Expand description
Returns true if the specified logging level is statically enabled
Valid arguments are: Error, Warn, Info, Debug and Trace
macro_rules! log_enabled {
($e:expr) => { ... };
}Returns true if the specified logging level is statically enabled
Valid arguments are: Error, Warn, Info, Debug and Trace