macro_rules! trace {
($($tt:tt)*) => { ... };
}Expand description
Logs a string at the ‘Trace’ logging level
Syntax matches uwriteln! minus the first argument. You need to depend on the ufmt crate to
use this macro.
NOTE a newline is always appended at the end